@@ -48,10 +48,6 @@ fake_responses = {
             {},
             {'images': [IMAGE1, IMAGE2]},
         ),
-        'SEARCH': (
-            {},
-            {'images': [IMAGE3]},
-        ),
     },
     '/v1/images/?limit=2':
     {
@@ -95,6 +91,14 @@ fake_responses = {
             {'images': [IMAGE2, IMAGE1]},
         ),
     },
+    '/v1/images/%s/search?image_driver=%s' % (IMAGE3['image'],
+                                              IMAGE3['image_driver']):
+    {
+        'GET': (
+            {},
+            {'images': [IMAGE3]},
+        ),
+    },
 }
 
 
@@ -179,10 +183,10 @@ class ImageManagerTest(testtools.TestCase):
 
     def test_image_search(self):
         images = self.mgr.search_image(**SEARCH_IMAGE)
+        url = '/v1/images/%s/search?image_driver=%s' \
+              % (IMAGE3['image'], IMAGE3['image_driver'])
         expect = [
-            ('SEARCH', '/v1/images/', {},
-             {'image': IMAGE3['image'],
-              'image_driver': IMAGE3['image_driver']}),
+            ('GET', url, {}, None),
         ]
         self.assertEqual(expect, self.api.calls)
         self.assertThat(images, matchers.HasLength(1))
